==> hs-concurrent-extra-0.7.0.4p3.tgz: lib/ghc/concurrent-extra-0.7.0.4/register.sh <==
#!/bin/sh
echo 'name: concurrent-extra
version: 0.7.0.4
id: concurrent-extra-0.7.0.4-d9b28f47065ab7f1ec28b99052c962a5

license: BSD3
copyright: (c) 2010-2011 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
stability: experimental
homepage: https://github.com/basvandijk/concurrent-extra
package-url:
synopsis: Extra concurrency primitives
description: The @concurrent-extra@ package offers among other things the
             following selection of synchronisation primitives:
             .
             * @Broadcast@: Wake multiple threads by broadcasting a value.
             .
             * @Event@: Wake multiple threads by signalling an event.
             .
             * @Lock@: Enforce exclusive access to a resource. Also known as a
             binary semaphore or mutex. The package additionally provides an
             alternative that works in the @STM@ monad.
             .
             * @RLock@: A lock which can be acquired multiple times by the same
             thread. Also known as a reentrant mutex.
             .
             * @ReadWriteLock@: Multiple-reader, single-writer locks. Used to
             protect shared resources which may be concurrently read, but only
             sequentially written.
             .
             * @ReadWriteVar@: Concurrent read, sequential write variables.
             .
             Please consult the API documentation of the individual modules for
             more detailed information.
             .
             This package was inspired by the concurrency libraries of Java and
             Python.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
pkgpath: devel/hs-concurrent-extra
exposed: True
exposed-modules: Control.Concurrent.Lock
                 Control.Concurrent.STM.Lock Control.Concurrent.RLock
                 Control.Concurrent.Event Control.Concurrent.Broadcast
                 Control.Concurrent.ReadWriteLock Control.Concurrent.ReadWriteVar
hidden-modules: Utils
trusted: False
import-dirs: /usr/local/lib/ghc/concurrent-extra-0.7.0.4
library-dirs: /usr/local/lib/ghc/concurrent-extra-0.7.0.4
hs-libraries: HSconcurrent-extra-0.7.0.4
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         base-unicode-symbols-0.2.2.4-47de1db137e54c7919bd23c17263184a
         stm-2.4-464c94c0d4d2a3fb7bf1cd1f8648d14d
         unbounded-delays-0.1.0.5-c704cbc4d2c5120d0499bed17bf02164
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-concurrent-extra-0.7.0.4/html/concurrent-extra.haddock
haddock-html: /usr/local/share/doc/hs-concurrent-extra-0.7.0.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-concurrent-extra-0.7.0.6.tgz: lib/ghc/concurrent-extra-0.7.0.6/register.sh <==
#!/bin/sh
echo 'name: concurrent-extra
version: 0.7.0.6
id: concurrent-extra-0.7.0.6-718367b29239e005f103a0a849d6e9cd

license: BSD3
copyright: (c) 2010-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
stability: experimental
homepage: https://github.com/basvandijk/concurrent-extra
package-url:
synopsis: Extra concurrency primitives
description: The @concurrent-extra@ package offers among other things the
             following selection of synchronisation primitives:
             .
             * @Broadcast@: Wake multiple threads by broadcasting a value.
             .
             * @Event@: Wake multiple threads by signalling an event.
             .
             * @Lock@: Enforce exclusive access to a resource. Also known as a
             binary semaphore or mutex. The package additionally provides an
             alternative that works in the @STM@ monad.
             .
             * @RLock@: A lock which can be acquired multiple times by the same
             thread. Also known as a reentrant mutex.
             .
             * @ReadWriteLock@: Multiple-reader, single-writer locks. Used to
             protect shared resources which may be concurrently read, but only
             sequentially written.
             .
             * @ReadWriteVar@: Concurrent read, sequential write variables.
             .
             Please consult the API documentation of the individual modules for
             more detailed information.
             .
             This package was inspired by the concurrency libraries of Java and
             Python.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
pkgpath: devel/hs-concurrent-extra
exposed: True
exposed-modules: Control.Concurrent.Lock
                 Control.Concurrent.STM.Lock Control.Concurrent.RLock
                 Control.Concurrent.Event Control.Concurrent.Broadcast
                 Control.Concurrent.ReadWriteLock Control.Concurrent.ReadWriteVar
hidden-modules: Utils
trusted: False
import-dirs: /usr/local/lib/ghc/concurrent-extra-0.7.0.6
library-dirs: /usr/local/lib/ghc/concurrent-extra-0.7.0.6
hs-libraries: HSconcurrent-extra-0.7.0.6
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
         base-unicode-symbols-0.2.2.4-ec1c787160bf91bc92b0b4f99c4199a9
         stm-2.4.2-b5d718b1a5f1fbcdb61a336aef0c2130
         unbounded-delays-0.1.0.5-83bcaf5ff5faa9715fff97b36d2fdadc
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-concurrent-extra-0.7.0.6/html/concurrent-extra.haddock
haddock-html: /usr/local/share/doc/hs-concurrent-extra-0.7.0.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
